@@ -138,14 +138,20 @@ class SentinelInterp(Interp):
     def load_test(self, jac_ast):
         """
         test:
-            KW_TEST STRING KW_WITH (graph_ref | KW_GRAPH graph_block) KW_BY (
+            KW_TEST NAME? STRING KW_WITH (
+                graph_ref
+                | KW_GRAPH graph_block
+            ) KW_BY (
                 (walker_ref spawn_ctx? (code_block | SEMI))
                 | KW_WALKER walker_block
             );
         """
         kid = self.set_cur_ast(jac_ast)
         testcase = {
-            "title": kid[1].token_text(),
+            "name": kid[1].token_text() if kid[1].name == "NAME" else "",
+            "title": kid[2].token_text()
+            if kid[1].name == "NAME"
+            else kid[1].token_text(),
             "graph_ref": None,
             "graph_block": None,
             "walker_ref": None,
@@ -154,7 +160,7 @@ class SentinelInterp(Interp):
             "walker_block": None,
             "outcome": None,
         }
-        kid = kid[3:]
+        kid = kid[4:] if kid[1].name == "NAME" else kid[3:]
         if kid[0].name == "graph_ref":
             graph_name = kid[0].kid[-1].token_text()
             if not self.arch_ids.has_obj_by_name(graph_name, kind="graph"):
